@@ -25,7 +25,13 @@ class GitbucketControl:
         self.systemd.stop()
         self.systemd.disable()
 
+    def _get_url(self, info):
+        url = '{0}://{1}:{2}'.format(info.service.protocol, info.external_host, info.external_port)
+        if info.service.url:
+            url += '/'+info.service.url
+        return url
+
     def url(self):
         self.systemd.check_active()
         info = self.insider.service_info(SERVICE_NAME)
-        return '{0}://{1}:{2}/{3}'.format(info.service.protocol, info.external_host, info.external_port, info.service.url)
\ No newline at end of file
+        return self._get_url(info)
\ No newline at end of file
