@@ -22,6 +22,10 @@ class SystemD:
     def stop(self):
         self._execute('stop')
 
-    def is_active(self):
-        status_text = self._execute('status', raise_on_bad_exit_code=False)
-        return 'Active: active' in status_text
\ No newline at end of file
+    def check_active(self):
+        try:
+            status_text = self._execute('status', raise_on_bad_exit_code=True)
+            if 'Active: active' not in status_text:
+                raise(Exception('GitBucket service is not active'))
+        except:
+            raise(Exception('GitBucket service is not active'))
\ No newline at end of file
